@@ -5,6 +5,8 @@ import random
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
+from qrtoolkit_core.validators import validate_is_api_mode_qrcode
+
 
 class ApiHit(models.Model):
     # noinspection PyPep8Naming
@@ -13,6 +15,7 @@ class ApiHit(models.Model):
         KIOSK = 'kiosk', _('Kiosk')
         JSON = 'json', _('Json Response')
         REDIRECT = 'redirect', _('Redirect')
+        API_CALL = 'api_call', _('Api Call')
         ERROR = 'error', _('Error')
 
     hit_date = models.DateTimeField(auto_now_add=True)
@@ -47,6 +50,9 @@ class LinkUrl(models.Model):
         on_delete=models.CASCADE,
         related_name='urls')
 
+    def __str__(self):
+        return f'"{self.name}" on code: "{self.code.title}"'
+
     class Meta:
         ordering = ['-priority']
 
@@ -55,7 +61,8 @@ QR_MODE_HELP_TEXT = """
 Sets the mode this code is in.<br/>
 Kiosk Mode: Show buttons to choose a link from<br/>
 Redirect Mode: Instantly redirects to the url with the highest priority.<br/>
-Information Page Mode: Show basic info with links to different urls.
+Information Page Mode: Show basic info with links to different urls.<br/>
+Api call Mode: Will look for ApiCall's in the database that correspond to the selected link_url, and execute them. (Extended Kiosk mode)
 """
 
 
@@ -65,6 +72,7 @@ class QRCode(models.Model):
         KIOSK = 'kiosk', _('Kiosk Mode')
         REDIRECT = 'redirect', _('Redirect Mode')
         INFO_PAGE = 'info_page', _('Information Page Mode')
+        API_CALL = 'api_call', _('Api call Mode')
 
     title = models.CharField(blank=True, default='', max_length=100, unique=True)
     department = models.ForeignKey(
@@ -105,7 +113,8 @@ class QRCode(models.Model):
 
 class ApiCall(models.Model):
     url = models.URLField()
-    code = models.ForeignKey(QRCode, on_delete=models.CASCADE, related_name='api_calls')
+    link_url = models.ForeignKey(LinkUrl, on_delete=models.CASCADE, related_name='api_calls',
+                                 validators=[validate_is_api_mode_qrcode])
     payload = models.TextField()
 
 
